@@ -27,8 +27,8 @@ G_BEGIN_DECLS
 
 gunichar *_g_utf8_normalize_wc       (const gchar    *str,
                                       gssize          max_len,
-                                      GNormalizeMode  mode);
-gint      _g_unichar_combining_class (gunichar uc);
+                                      GNormalizeMode  mode) G_GNUC_INTERNAL;
+gint      _g_unichar_combining_class (gunichar uc) G_GNUC_INTERNAL;
 
 G_END_DECLS
 
